// sensor @ 12,13 scouts user within 50cm
// if user detected, LED eyes turn on + timer starts (t=)

// if button pressed within t=5s of timer start
// servo motor rotates 40 deg to open beak
// else, LED eyes shut back off

// after beak opens, delay 7s (for candy withdrawl/refill)
// servo motor rotates -40 deg (back to original position)
// LED eyes turn off ~simultaneously

// 5s cooldown before toucan can be reactivated
// repeat forever

#include <Servo.h> // load servo library
Servo myservo;  // create servo object

unsigned long startMillis; // init. timer begin point
unsigned long currentMillis; // init. timer reading point
const unsigned long wait = 5000; // 5s limit for timer

int LED1 = 2;  // arduino pin for 1 LED eye
int LED2 = 3; // arduino pin for other LED eye
int threshold = 50; // threshold distance for user (cm)
double convert = 0.01; // conversion from US sensor reading to cm
double dist = 0; // init. distance reading
int angle = 40; // angle for servo to rotate
int trig = 13; // US sensor trigger pin
int echo = 12; // US sensor echo pin
int longpause = 7000; // 7s pause
int pause = 1000; // 1s pause

long readUltrasonicDistance(int triggerPin, int echoPin)
{
  pinMode(triggerPin, OUTPUT);  // clear trigger
  digitalWrite(triggerPin, LOW);
  delayMicroseconds(2);
  // set trigger pin to HIGH for 10 microseconds
  digitalWrite(triggerPin, HIGH);
  delayMicroseconds(10);
  digitalWrite(triggerPin, LOW);
  pinMode(echoPin, INPUT);
  // read echo pin, returns travel time (microseconds)
  return pulseIn(echoPin, HIGH);
}

void setup()
{
  myservo.write(0);
  pinMode(LED1, OUTPUT);
  pinMode(LED2, OUTPUT);
  Serial.begin(9600);
  Serial.print("begin\n");
  myservo.attach(9); // pin to drive servo
}

void loop()
{
  // check user within 50cm (long range)
  dist = convert*readUltrasonicDistance(trig,echo);
  Serial.print(".");

  // if user within 50cm:
  if(dist<threshold){ // turn on eyes + start 'active' period
    Serial.print("\ndistance (cm): ");
    Serial.print(dist);
    Serial.print("\nuser detected! pull up \n");
    digitalWrite(LED1,HIGH);
    digitalWrite(LED2,HIGH);
    delay(pause);
    startMillis = millis();  // initial start time
    
    // open beak if button pressed during active period
    Serial.print(digitalRead(6));
    while(millis()-startMillis<=wait){ // active during 5s wait
      if(digitalRead(6)==HIGH){ // if button pressed
        Serial.print("user pulled up! have a snack \n");
        myservo.write(angle);
        delay(longpause);
        myservo.write(0);
        Serial.print("thanks for coming! \n");
        break;
      }
    }
    
    // turn off eyes once deactivated
    Serial.print("back to chilling \n");
    digitalWrite(LED1,LOW);
    digitalWrite(LED2,LOW);
    delay(longpause);
  }

}
